# -*- coding: utf-8 -*-

from rest_framework import serializers

from ... import models
from apps.role.core.serializers import ThuxRoleSerializerMixin
from thx.api.serializers import ThuxCreateSerializerMixin, ThuxUpdateSerializerMixin


# PROJECT TYPE
class ProjectTypeSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_project_project_type'
        model = models.ProjectType
        fields = '__all__'


class ProjectTypeCreateSerializer(
    ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer
):

    def to_representation(self, instance):
        return ProjectTypeSerializer(instance, context=self.context).data

    class Meta:
        ref_name = 'v1_project_project_type_create'
        model = models.ProjectType
        fields = '__all__'


class ProjectTypeUpdateSerializer(
    ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer
):

    def to_representation(self, instance):
        return ProjectTypeSerializer(instance, context=self.context).data

    class Meta:
        ref_name = 'v1_project_project_type_update'
        model = models.ProjectType
        fields = '__all__'


class ProjectTypeEnableSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance

    class Meta:
        ref_name = 'v1_project_project_type_enable'
        model = models.ProjectType
        fields = '__all__'

    def to_representation(self, instance):
        return ProjectTypeSerializer(instance, context=self.context).data


class ProjectTypeDisableSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance

    class Meta:
        ref_name = 'v1_project_project_type_disable'
        model = models.ProjectType
        fields = '__all__'

    def to_representation(self, instance):
        return ProjectTypeSerializer(instance, context=self.context).data


# PROJECT
class ProjectSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_project_project'
        model = models.Project
        fields = '__all__'


class ProjectCreateSerializer(
    ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer
):

    def to_representation(self, instance):
        return ProjectSerializer(instance, context=self.context).data

    class Meta:
        ref_name = 'v1_project_project_create'
        model = models.Project
        fields = '__all__'


class ProjectUpdateSerializer(
    ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer
):

    def to_representation(self, instance):
        return ProjectSerializer(instance, context=self.context).data

    class Meta:
        ref_name = 'v1_project_project_update'
        model = models.Project
        fields = '__all__'


class ProjectEnableSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance

    class Meta:
        ref_name = 'v1_project_project_enable'
        model = models.Project
        fields = '__all__'

    def to_representation(self, instance):
        return ProjectSerializer(instance, context=self.context).data


class ProjectDisableSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance

    class Meta:
        ref_name = 'v1_project_project_disable'
        model = models.Project
        fields = '__all__'

    def to_representation(self, instance):
        return ProjectSerializer(instance, context=self.context).data


# PROJECT NUMBER
class ProjectNumberSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_project_project_number'
        model = models.ProjectNumber
        fields = '__all__'


class ProjectNumberCreateSerializer(
    ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer
):

    def to_representation(self, instance):
        return ProjectNumberSerializer(instance, context=self.context).data

    class Meta:
        ref_name = 'v1_project_project_number_create'
        model = models.ProjectNumber
        fields = '__all__'


class ProjectNumberUpdateSerializer(
    ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer
):

    def to_representation(self, instance):
        return ProjectNumberSerializer(instance, context=self.context).data

    class Meta:
        ref_name = 'v1_project_project_number_update'
        model = models.ProjectNumber
        fields = '__all__'


class ProjectNumberEnableSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance

    class Meta:
        ref_name = 'v1_project_project_number_enable'
        model = models.ProjectNumber
        fields = '__all__'

    def to_representation(self, instance):
        return ProjectNumberSerializer(instance, context=self.context).data


class ProjectNumberDisableSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance

    class Meta:
        ref_name = 'v1_project_project_number_disable'
        model = models.ProjectNumber
        fields = '__all__'

    def to_representation(self, instance):
        return ProjectNumberSerializer(instance, context=self.context).data
